@@ -97,17 +97,29 @@ def read_xml_annotation(xml_dir, image_id):
 
 
 def change_xml_list_annotation(xml_dir, image_id, new_target, method_num, epoch):
-    in_file = open(os.path.join(xml_dir, str(image_id) + '.xml'), encoding='utf8')  # 读取原来的xml文件
+    in_file = open(os.path.join(xml_dir, image_id + '.xml'))  # 读取原来的xml文件
     tree = ET.parse(in_file)  # 读取xml文件
     xmlroot = tree.getroot()
+    size = xmlroot.find("size")
+    width = int(size.find("width").text)
+    height = int(size.find("height").text)
     index = 0
     # 将bbox中原来的坐标值换成新生成的坐标值
     for object in xmlroot.findall('object'):  # 找到root节点下的所有country节点
         bndbox = object.find('bndbox')  # 子节点下节点rank的值
-        bndbox.find('xmin').text = str(new_target[index][0])
-        bndbox.find('ymin').text = str(new_target[index][1])
-        bndbox.find('xmax').text = str(new_target[index][2])
-        bndbox.find('ymax').text = str(new_target[index][3])
+        new_xmin = new_target[index][0]
+        new_ymin = new_target[index][1]
+        new_xmax = new_target[index][2]
+        new_ymax = new_target[index][3]
+
+        xmin = bndbox.find('xmin')
+        xmin.text = str(max(new_xmin, 0))
+        ymin = bndbox.find('ymin')
+        ymin.text = str(max(new_ymin, 0))
+        xmax = bndbox.find('xmax')
+        xmax.text = str(min(new_xmax, width))
+        ymax = bndbox.find('ymax')
+        ymax.text = str(min(new_ymax, height))
         index = index + 1
     tree.write(os.path.join(xml_dir, "imgaug_%s_%s_" % (method_num + 1, epoch) + str(image_id) + '.xml'))
 
